@@ -1,7 +1,8 @@
 package WebService::Solr::Response;
 
-use Moose;
+use Moo;
 
+use Types::Standard qw(Object HashRef Maybe InstanceOf ArrayRef);
 use WebService::Solr::Document;
 use Data::Page;
 use Data::Pageset;
@@ -9,7 +10,7 @@ use JSON::XS ();
 
 has 'raw_response' => (
     is      => 'ro',
-    isa     => 'Object',
+    isa     => Object,
     handles => {
         status_code    => 'code',
         status_message => 'message',
@@ -18,17 +19,23 @@ has 'raw_response' => (
     },
 );
 
-has 'content' => ( is => 'rw', isa => 'HashRef', lazy_build => 1 );
+has 'content' => ( is => 'lazy', isa => HashRef );
 
 has 'docs' =>
-    ( is => 'rw', isa => 'ArrayRef', auto_deref => 1, lazy_build => 1 );
+    ( is => 'lazy', isa => ArrayRef );
 
-has 'pager' => ( is => 'rw', isa => 'Maybe[Data::Page]', lazy_build => 1 );
+around docs => sub {
+    my ($orig, $self, @args) = @_;
+    my $ret = $self->$orig(@args);
+    return wantarray ? @$ret : $ret;
+};
+
+has 'pager' => ( is => 'lazy', isa => Maybe[InstanceOf['Data::Page']] );
 
 has '_pageset_slide' =>
-    ( is => 'rw', isa => 'Maybe[Data::Pageset]', lazy_build => 1 );
+    ( is => 'rw', isa => Maybe[InstanceOf['Data::Pageset']], predicate => 1 );
 has '_pageset_fixed' =>
-    ( is => 'rw', isa => 'Maybe[Data::Pageset]', lazy_build => 1 );
+    ( is => 'rw', isa => Maybe[InstanceOf['Data::Pageset']], predicate => 1 );
 
 sub BUILDARGS {
     my ( $self, $res ) = @_;
@@ -65,14 +72,10 @@ sub _build_pager {
     return unless exists $struct->{ response }->{ numFound };
 
     my $rows = $struct->{ responseHeader }->{ params }->{ rows };
-
-    # rows not explicitly set, find default from rows returned
-    if ( !defined $rows ) {
-        $rows = scalar @{ $struct->{ response }->{ docs } };
-    }
+    $rows = 10 unless defined $rows;
 
     # do not generate a pager for queries explicitly requesting no rows
-    return if defined $rows && $rows == 0;
+    return if $rows == 0;
 
     my $pager = Data::Page->new;
     $pager->total_entries( $struct->{ response }->{ numFound } );
@@ -105,14 +108,10 @@ sub _build_pageset {
     return unless exists $struct->{ response }->{ numFound };
 
     my $rows = $struct->{ responseHeader }->{ params }->{ rows };
+    $rows = 10 unless defined $rows;
 
     # do not generate a pager for queries explicitly requesting no rows
-    return if defined $rows && $rows == 0;
-
-    # rows not explicitly set, find default from rows returned
-    if ( !defined $rows ) {
-        $rows = scalar @{ $struct->{ response }->{ docs } };
-    }
+    return if $rows == 0;
 
     my $pager = Data::Pageset->new(
         {   total_entries    => $struct->{ response }->{ numFound },
@@ -144,9 +143,7 @@ sub ok {
     return defined $status && $status == 0;
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
+no Moo;
 
 1;
 
@@ -195,7 +192,7 @@ required.
 
 =head2 BUILDARGS( @args )
 
-A Moose override to allow our custom constructor.
+A Moo override to allow our custom constructor.
 
 =head2 facet_counts( )
 
@@ -215,16 +212,19 @@ Calls C<solr_status()> and check that it is equal to 0.
 
 =head1 AUTHORS
 
+Andy Lester C<andy@petdance.com>
+
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
-Kirk Beers E<lt>kirk.beers@nald.caE<gt>
+Kirk Beers
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2010 National Adult Literacy Database
+Copyright 2008-2014 National Adult Literacy Database
+Copyright 2015-2020 Andy Lester
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =cut
 
